"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
var generateResponsiveClasses_1 = __importDefault(require("./generateResponsiveClasses"));
describe('generateResponsiveClasses', function () {
    it('should generate class names with breakpoints, excluding "xs"', function () {
        expect((0, generateResponsiveClasses_1.default)('d', { xs: 'none', sm: 'block' })).toEqual({
            'd-none': true,
            'd-sm-block': true
        });
    });
    it('should generate class names with a single value', function () {
        expect((0, generateResponsiveClasses_1.default)('float', 'end')).toEqual({ 'float-end': true });
    });
    it('should return an empty object for undefined values', function () {
        expect((0, generateResponsiveClasses_1.default)('float', undefined)).toEqual({});
    });
    // New test case for boolean value with a suffix
    it('should generate class names with a boolean value and suffix', function () {
        expect((0, generateResponsiveClasses_1.default)('flex', true, 'fill')).toEqual({ 'flex-fill': true });
    });
    // New test case for boolean value with breakpoints and suffix
    it('should generate class names with boolean breakpoints and suffix', function () {
        expect((0, generateResponsiveClasses_1.default)('flex', { sm: true, lg: true }, 'grow')).toEqual({
            'flex-sm-grow': true,
            'flex-lg-grow': true
        });
    });
    // New test case for a mixed object with strings and boolean values
    it('should generate class names with mixed strings and boolean values', function () {
        expect((0, generateResponsiveClasses_1.default)('flex', { xs: 'row', sm: true, md: 'column', lg: true }, 'grow')).toEqual({
            'flex-row': true,
            'flex-sm-grow': true,
            'flex-md-column': true,
            'flex-lg-grow': true
        });
    });
});
